aboutsummaryrefslogtreecommitdiff
path: root/src/include/parser/parse_agg.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/parser/parse_agg.h')
-rw-r--r--src/include/parser/parse_agg.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/include/parser/parse_agg.h b/src/include/parser/parse_agg.h
index bf3574e89fc..93b7f674e32 100644
--- a/src/include/parser/parse_agg.h
+++ b/src/include/parser/parse_agg.h
@@ -1,12 +1,12 @@
/*-------------------------------------------------------------------------
*
* parse_agg.h
* handle aggregates in parser
*
* Portions Copyright (c) 1996-2008, PostgreSQL Global Development Group
* Portions Copyright (c) 1994, Regents of the University of California
*
- * $PostgreSQL: pgsql/src/include/parser/parse_agg.h,v 1.36 2008/01/01 19:45:58 momjian Exp $
+ * $PostgreSQL: pgsql/src/include/parser/parse_agg.h,v 1.37 2008/12/28 18:54:01 tgl Exp $
*
*-------------------------------------------------------------------------
*/
@@ -16,8 +16,11 @@
#include "parser/parse_node.h"
extern void transformAggregateCall(ParseState *pstate, Aggref *agg);
+extern void transformWindowFuncCall(ParseState *pstate, WindowFunc *wfunc,
+ WindowDef *windef);
extern void parseCheckAggregates(ParseState *pstate, Query *qry);
+extern void parseCheckWindowFuncs(ParseState *pstate, Query *qry);
extern void build_aggregate_fnexprs(Oid *agg_input_types,
int agg_num_inputs,
@@ -1,12 +1,12 @@
*
* parse_agg.h
- * handle aggregates in parser
+ * handle aggregates and window functions in parser
*
* Portions Copyright (c) 1996-2008, PostgreSQL Global Development Group